package Parley::Contributors;
use strict;
use Parley::Version;  our $VERSION = $Parley::VERSION;

# this is a dummy package to provide POD

1;

__END__

=pod

=head1 NAME

Parley::Contributors - people that helped out along the way

=head1 AUTHOR

Chisel Wright C<< <chiselwright@users.berlios.de> >>

=head1 INTERFACE

=head2 Icons

L<FamFamFam Silk Icons|http://www.famfamfam.com/lab/icons/silk/>

L<FamFamFam Flag Icons|http://www.famfamfam.com/lab/icons/flags/>

=head1 I18N

=head2 Dutch

Translation by Rob Partridge

Additional translations by Kevin Golding

=head2 Italian

Translation by Darius Jokilehto

=head1 PATCHES AND BUG-FIXES

Toby Corkindale C<< TJC >>

Kaare Rasmussen C<< CPANID: KAARE >>

=head1 PROJECTS

L<Catalyst>,
L<DBIx::Class>,
L<Yahoo! User Interface Library|http://developer.yahoo.com/yui/>

=cut
